@@ -10,7 +10,12 @@
 #' getnumericCols(iris)
 #' getnumericCols(mtcars)
 getnumericCols <- function(dat) {
-  x <- as.data.frame(do.call("rbind", lapply(names(dat), FUN = function(x){c(x, class(dat[[x]]))})))
+  x <- as.data.frame(do.call("rbind",
+                             lapply(names(dat),
+                                    FUN = function(x) {
+                                      c(x, class(dat[[x]]))
+                                    })))
+
   names(x) <- c("name", "type")
   x <- x[x$type %in% c("integer", "numeric"), ]$name %>% as.vector()
   return(x)
@@ -24,21 +29,18 @@ getnumericCols <- function(dat) {
 #' @return A Character vector of names of numeric columns of a given data frame
 #' @export
 #' @import dplyr
-#' @examples 
+#' @examples
 #' getcharacterCols(iris)
 #' getcharacterCols(mtcars)
 getcharacterCols <- function(dat) {
-  
-  x <- do.call("rbind", 
-               lapply(names(dat), FUN = function(x){ 
-               c(x, class(dat[[x]]))
-                 
-               })
-       ) %>% as.data.frame()
-  
+  x <- do.call("rbind",
+               lapply(names(dat),
+                      FUN = function(x) {
+                        c(x, class(dat[[x]]))})) %>% as.data.frame()
+
   names(x) <- c("name", "type")
-  
-  x <- x[x$type %in% c("character","factor"), ]$name %>% as.vector()
+
+  x <- x[x$type %in% c("character", "factor"), ]$name %>% as.vector()
 
   return(x)
 }
